@@ -11,6 +11,8 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
+set -e
+
 . ../conf.sh
 
 DIGOPTS="+short -p ${PORT}"
@@ -29,7 +31,7 @@ dnstap_data_ready() {
 	min_size_expected=$3
 
 	kill -HUP $fstrm_capture_pid
-	file_size=`wc -c < "$capture_file" | tr -d ' '`
+	file_size=$(wc -c < "$capture_file" | tr -d ' ')
 	if [ $file_size -lt $min_size_expected ]; then
 		return 1
 	fi
@@ -40,18 +42,18 @@ for bad in bad-*.conf
 do
 	ret=0
 	echo_i "checking that named-checkconf detects error in $bad"
-	$CHECKCONF $bad > /dev/null 2>&1
-	if [ $? != 1 ]; then echo_i "failed"; ret=1; fi
-	status=`expr $status + $ret`
+	{ $CHECKCONF $bad > /dev/null 2>&1; rc=$?; } || true
+	if [ $rc != 1 ]; then echo_i "failed"; ret=1; fi
+	status=$((status + ret))
 done
 
 for good in good-*.conf
 do
 	ret=0
 	echo_i "checking that named-checkconf detects no error in $good"
-	$CHECKCONF $good > /dev/null 2>&1
-	if [ $? != 0 ]; then echo_i "failed"; ret=1; fi
-	status=`expr $status + $ret`
+	{ $CHECKCONF $good > /dev/null 2>&1; rc=$?; } || true
+	if [ $rc != 0 ]; then echo_i "failed"; ret=1; fi
+	status=$((status + ret))
 done
 
 echo_i "wait for servers to finish loading"
@@ -61,7 +63,7 @@ wait_for_log 20 "all zones loaded" ns2/named.run || ret=1
 wait_for_log 20 "all zones loaded" ns3/named.run || ret=1
 wait_for_log 20 "all zones loaded" ns4/named.run || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 # both the 'a.example/A' lookup and the './NS' lookup to ns1
 # need to complete before reopening/rolling for the counts to
@@ -109,39 +111,39 @@ sleep 1
 
 echo_i "checking initial message counts"
 
-udp1=`$DNSTAPREAD ns1/dnstap.out.save | grep "UDP " | wc -l`
-tcp1=`$DNSTAPREAD ns1/dnstap.out.save | grep "TCP " | wc -l`
-aq1=`$DNSTAPREAD ns1/dnstap.out.save | grep "AQ " | wc -l`
-ar1=`$DNSTAPREAD ns1/dnstap.out.save | grep "AR " | wc -l`
-cq1=`$DNSTAPREAD ns1/dnstap.out.save | grep "CQ " | wc -l`
-cr1=`$DNSTAPREAD ns1/dnstap.out.save | grep "CR " | wc -l`
-rq1=`$DNSTAPREAD ns1/dnstap.out.save | grep "RQ " | wc -l`
-rr1=`$DNSTAPREAD ns1/dnstap.out.save | grep "RR " | wc -l`
-uq1=`$DNSTAPREAD ns1/dnstap.out.save | grep "UQ " | wc -l`
-ur1=`$DNSTAPREAD ns1/dnstap.out.save | grep "UR " | wc -l`
+udp1=$($DNSTAPREAD ns1/dnstap.out.save | grep "UDP " | wc -l)
+tcp1=$($DNSTAPREAD ns1/dnstap.out.save | grep "TCP " | wc -l)
+aq1=$($DNSTAPREAD ns1/dnstap.out.save | grep "AQ " | wc -l)
+ar1=$($DNSTAPREAD ns1/dnstap.out.save | grep "AR " | wc -l)
+cq1=$($DNSTAPREAD ns1/dnstap.out.save | grep "CQ " | wc -l)
+cr1=$($DNSTAPREAD ns1/dnstap.out.save | grep "CR " | wc -l)
+rq1=$($DNSTAPREAD ns1/dnstap.out.save | grep "RQ " | wc -l)
+rr1=$($DNSTAPREAD ns1/dnstap.out.save | grep "RR " | wc -l)
+uq1=$($DNSTAPREAD ns1/dnstap.out.save | grep "UQ " | wc -l)
+ur1=$($DNSTAPREAD ns1/dnstap.out.save | grep "UR " | wc -l)
 
-udp2=`$DNSTAPREAD ns2/dnstap.out.save | grep "UDP " | wc -l`
-tcp2=`$DNSTAPREAD ns2/dnstap.out.save | grep "TCP " | wc -l`
-aq2=`$DNSTAPREAD ns2/dnstap.out.save | grep "AQ " | wc -l`
-ar2=`$DNSTAPREAD ns2/dnstap.out.save | grep "AR " | wc -l`
-cq2=`$DNSTAPREAD ns2/dnstap.out.save | grep "CQ " | wc -l`
-cr2=`$DNSTAPREAD ns2/dnstap.out.save | grep "CR " | wc -l`
-rq2=`$DNSTAPREAD ns2/dnstap.out.save | grep "RQ " | wc -l`
-rr2=`$DNSTAPREAD ns2/dnstap.out.save | grep "RR " | wc -l`
-uq2=`$DNSTAPREAD ns2/dnstap.out.save | grep "UQ " | wc -l`
-ur2=`$DNSTAPREAD ns2/dnstap.out.save | grep "UR " | wc -l`
+udp2=$($DNSTAPREAD ns2/dnstap.out.save | grep "UDP " | wc -l)
+tcp2=$($DNSTAPREAD ns2/dnstap.out.save | grep "TCP " | wc -l)
+aq2=$($DNSTAPREAD ns2/dnstap.out.save | grep "AQ " | wc -l)
+ar2=$($DNSTAPREAD ns2/dnstap.out.save | grep "AR " | wc -l)
+cq2=$($DNSTAPREAD ns2/dnstap.out.save | grep "CQ " | wc -l)
+cr2=$($DNSTAPREAD ns2/dnstap.out.save | grep "CR " | wc -l)
+rq2=$($DNSTAPREAD ns2/dnstap.out.save | grep "RQ " | wc -l)
+rr2=$($DNSTAPREAD ns2/dnstap.out.save | grep "RR " | wc -l)
+uq2=$($DNSTAPREAD ns2/dnstap.out.save | grep "UQ " | wc -l)
+ur2=$($DNSTAPREAD ns2/dnstap.out.save | grep "UR " | wc -l)
 
 mv ns3/dnstap.out.0 ns3/dnstap.out.save
-udp3=`$DNSTAPREAD ns3/dnstap.out.save | grep "UDP " | wc -l`
-tcp3=`$DNSTAPREAD ns3/dnstap.out.save | grep "TCP " | wc -l`
-aq3=`$DNSTAPREAD ns3/dnstap.out.save | grep "AQ " | wc -l`
-ar3=`$DNSTAPREAD ns3/dnstap.out.save | grep "AR " | wc -l`
-cq3=`$DNSTAPREAD ns3/dnstap.out.save | grep "CQ " | wc -l`
-cr3=`$DNSTAPREAD ns3/dnstap.out.save | grep "CR " | wc -l`
-rq3=`$DNSTAPREAD ns3/dnstap.out.save | grep "RQ " | wc -l`
-rr3=`$DNSTAPREAD ns3/dnstap.out.save | grep "RR " | wc -l`
-uq3=`$DNSTAPREAD ns3/dnstap.out.save | grep "UQ " | wc -l`
-ur3=`$DNSTAPREAD ns3/dnstap.out.save | grep "UR " | wc -l`
+udp3=$($DNSTAPREAD ns3/dnstap.out.save | grep "UDP " | wc -l)
+tcp3=$($DNSTAPREAD ns3/dnstap.out.save | grep "TCP " | wc -l)
+aq3=$($DNSTAPREAD ns3/dnstap.out.save | grep "AQ " | wc -l)
+ar3=$($DNSTAPREAD ns3/dnstap.out.save | grep "AR " | wc -l)
+cq3=$($DNSTAPREAD ns3/dnstap.out.save | grep "CQ " | wc -l)
+cr3=$($DNSTAPREAD ns3/dnstap.out.save | grep "CR " | wc -l)
+rq3=$($DNSTAPREAD ns3/dnstap.out.save | grep "RQ " | wc -l)
+rr3=$($DNSTAPREAD ns3/dnstap.out.save | grep "RR " | wc -l)
+uq3=$($DNSTAPREAD ns3/dnstap.out.save | grep "UQ " | wc -l)
+ur3=$($DNSTAPREAD ns3/dnstap.out.save | grep "UR " | wc -l)
 
 echo_i "checking UDP message counts"
 ret=0
@@ -158,7 +160,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking TCP message counts"
 ret=0
@@ -175,7 +177,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking AUTH_QUERY message counts"
 ret=0
@@ -192,7 +194,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking AUTH_RESPONSE message counts"
 ret=0
@@ -209,7 +211,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking CLIENT_QUERY message counts"
 ret=0
@@ -226,7 +228,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking CLIENT_RESPONSE message counts"
 ret=0
@@ -243,7 +245,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking RESOLVER_QUERY message counts"
 ret=0
@@ -260,7 +262,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking RESOLVER_RESPONSE message counts"
 ret=0
@@ -277,7 +279,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking UPDATE_QUERY message counts"
 ret=0
@@ -294,7 +296,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking UPDATE_RESPONSE message counts"
 ret=0
@@ -311,42 +313,42 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking reopened message counts"
 
-udp1=`$DNSTAPREAD ns1/dnstap.out | grep "UDP " | wc -l`
-tcp1=`$DNSTAPREAD ns1/dnstap.out | grep "TCP " | wc -l`
-aq1=`$DNSTAPREAD ns1/dnstap.out | grep "AQ " | wc -l`
-ar1=`$DNSTAPREAD ns1/dnstap.out | grep "AR " | wc -l`
-cq1=`$DNSTAPREAD ns1/dnstap.out | grep "CQ " | wc -l`
-cr1=`$DNSTAPREAD ns1/dnstap.out | grep "CR " | wc -l`
-rq1=`$DNSTAPREAD ns1/dnstap.out | grep "RQ " | wc -l`
-rr1=`$DNSTAPREAD ns1/dnstap.out | grep "RR " | wc -l`
-uq1=`$DNSTAPREAD ns1/dnstap.out | grep "UQ " | wc -l`
-ur1=`$DNSTAPREAD ns1/dnstap.out | grep "UR " | wc -l`
+udp1=$($DNSTAPREAD ns1/dnstap.out | grep "UDP " | wc -l)
+tcp1=$($DNSTAPREAD ns1/dnstap.out | grep "TCP " | wc -l)
+aq1=$($DNSTAPREAD ns1/dnstap.out | grep "AQ " | wc -l)
+ar1=$($DNSTAPREAD ns1/dnstap.out | grep "AR " | wc -l)
+cq1=$($DNSTAPREAD ns1/dnstap.out | grep "CQ " | wc -l)
+cr1=$($DNSTAPREAD ns1/dnstap.out | grep "CR " | wc -l)
+rq1=$($DNSTAPREAD ns1/dnstap.out | grep "RQ " | wc -l)
+rr1=$($DNSTAPREAD ns1/dnstap.out | grep "RR " | wc -l)
+uq1=$($DNSTAPREAD ns1/dnstap.out | grep "UQ " | wc -l)
+ur1=$($DNSTAPREAD ns1/dnstap.out | grep "UR " | wc -l)
 
-udp2=`$DNSTAPREAD ns2/dnstap.out | grep "UDP " | wc -l`
-tcp2=`$DNSTAPREAD ns2/dnstap.out | grep "TCP " | wc -l`
-aq2=`$DNSTAPREAD ns2/dnstap.out | grep "AQ " | wc -l`
-ar2=`$DNSTAPREAD ns2/dnstap.out | grep "AR " | wc -l`
-cq2=`$DNSTAPREAD ns2/dnstap.out | grep "CQ " | wc -l`
-cr2=`$DNSTAPREAD ns2/dnstap.out | grep "CR " | wc -l`
-rq2=`$DNSTAPREAD ns2/dnstap.out | grep "RQ " | wc -l`
-rr2=`$DNSTAPREAD ns2/dnstap.out | grep "RR " | wc -l`
-uq2=`$DNSTAPREAD ns2/dnstap.out | grep "UQ " | wc -l`
-ur2=`$DNSTAPREAD ns2/dnstap.out | grep "UR " | wc -l`
+udp2=$($DNSTAPREAD ns2/dnstap.out | grep "UDP " | wc -l)
+tcp2=$($DNSTAPREAD ns2/dnstap.out | grep "TCP " | wc -l)
+aq2=$($DNSTAPREAD ns2/dnstap.out | grep "AQ " | wc -l)
+ar2=$($DNSTAPREAD ns2/dnstap.out | grep "AR " | wc -l)
+cq2=$($DNSTAPREAD ns2/dnstap.out | grep "CQ " | wc -l)
+cr2=$($DNSTAPREAD ns2/dnstap.out | grep "CR " | wc -l)
+rq2=$($DNSTAPREAD ns2/dnstap.out | grep "RQ " | wc -l)
+rr2=$($DNSTAPREAD ns2/dnstap.out | grep "RR " | wc -l)
+uq2=$($DNSTAPREAD ns2/dnstap.out | grep "UQ " | wc -l)
+ur2=$($DNSTAPREAD ns2/dnstap.out | grep "UR " | wc -l)
 
-udp3=`$DNSTAPREAD ns3/dnstap.out | grep "UDP " | wc -l`
-tcp3=`$DNSTAPREAD ns3/dnstap.out | grep "TCP " | wc -l`
-aq3=`$DNSTAPREAD ns3/dnstap.out | grep "AQ " | wc -l`
-ar3=`$DNSTAPREAD ns3/dnstap.out | grep "AR " | wc -l`
-cq3=`$DNSTAPREAD ns3/dnstap.out | grep "CQ " | wc -l`
-cr3=`$DNSTAPREAD ns3/dnstap.out | grep "CR " | wc -l`
-rq3=`$DNSTAPREAD ns3/dnstap.out | grep "RQ " | wc -l`
-rr3=`$DNSTAPREAD ns3/dnstap.out | grep "RR " | wc -l`
-uq3=`$DNSTAPREAD ns3/dnstap.out | grep "UQ " | wc -l`
-ur3=`$DNSTAPREAD ns3/dnstap.out | grep "UR " | wc -l`
+udp3=$($DNSTAPREAD ns3/dnstap.out | grep "UDP " | wc -l)
+tcp3=$($DNSTAPREAD ns3/dnstap.out | grep "TCP " | wc -l)
+aq3=$($DNSTAPREAD ns3/dnstap.out | grep "AQ " | wc -l)
+ar3=$($DNSTAPREAD ns3/dnstap.out | grep "AR " | wc -l)
+cq3=$($DNSTAPREAD ns3/dnstap.out | grep "CQ " | wc -l)
+cr3=$($DNSTAPREAD ns3/dnstap.out | grep "CR " | wc -l)
+rq3=$($DNSTAPREAD ns3/dnstap.out | grep "RQ " | wc -l)
+rr3=$($DNSTAPREAD ns3/dnstap.out | grep "RR " | wc -l)
+uq3=$($DNSTAPREAD ns3/dnstap.out | grep "UQ " | wc -l)
+ur3=$($DNSTAPREAD ns3/dnstap.out | grep "UR " | wc -l)
 
 echo_i "checking UDP message counts"
 ret=0
@@ -363,7 +365,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking TCP message counts"
 ret=0
@@ -380,7 +382,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking AUTH_QUERY message counts"
 ret=0
@@ -397,7 +399,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking AUTH_RESPONSE message counts"
 ret=0
@@ -414,7 +416,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking CLIENT_QUERY message counts"
 ret=0
@@ -431,7 +433,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking CLIENT_RESPONSE message counts"
 ret=0
@@ -448,7 +450,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking RESOLVER_QUERY message counts"
 ret=0
@@ -465,7 +467,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking RESOLVER_RESPONSE message counts"
 ret=0
@@ -482,7 +484,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking UPDATE_QUERY message counts"
 ret=0
@@ -499,7 +501,7 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking UPDATE_RESPONSE message counts"
 ret=0
@@ -516,13 +518,13 @@ ret=0
 	ret=1
 }
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "checking whether destination UDP port is logged for client queries"
 ret=0
 $DNSTAPREAD ns3/dnstap.out.save | grep -Eq "CQ [0-9:.]+ -> 10.53.0.3:${PORT} UDP" || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 HAS_PYYAML=0
 if [ -x "$PYTHON" ] ; then
@@ -536,23 +538,23 @@ if [ $HAS_PYYAML -ne 0 ] ; then
 	  $PYTHON ydump.py "$DNSTAPREAD" "ns3/dnstap.out.save" > ydump.out || ret=1
         } | cat_i
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 fi
 
 echo_i "checking dnstap-read hex output"
 ret=0
-hex=`$DNSTAPREAD -x ns3/dnstap.out | tail -1`
+hex=$($DNSTAPREAD -x ns3/dnstap.out | tail -1)
 echo $hex | $WIRETEST > dnstap.hex
 grep 'status: NOERROR' dnstap.hex > /dev/null 2>&1 || ret=1
 grep 'ANSWER: 3, AUTHORITY: 1' dnstap.hex > /dev/null 2>&1 || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 if [ -n "$FSTRM_CAPTURE" ] ; then
 	$DIG $DIGOPTS @10.53.0.4 a.example > dig.out
 
 	# send an UPDATE to ns4
-	$NSUPDATE <<- EOF > nsupdate.out 2>&1
+	$NSUPDATE <<- EOF > nsupdate.out 2>&1 && ret=1
 	server 10.53.0.4 ${PORT}
 	zone example
 	update add b.example 3600 in a 10.10.10.10
@@ -570,16 +572,16 @@ EOF
 	status=$((status + ret))
 	kill $fstrm_capture_pid
 	wait
-	udp4=`$DNSTAPREAD dnstap.out | grep "UDP " | wc -l`
-	tcp4=`$DNSTAPREAD dnstap.out | grep "TCP " | wc -l`
-	aq4=`$DNSTAPREAD dnstap.out | grep "AQ " | wc -l`
-	ar4=`$DNSTAPREAD dnstap.out | grep "AR " | wc -l`
-	cq4=`$DNSTAPREAD dnstap.out | grep "CQ " | wc -l`
-	cr4=`$DNSTAPREAD dnstap.out | grep "CR " | wc -l`
-	rq4=`$DNSTAPREAD dnstap.out | grep "RQ " | wc -l`
-	rr4=`$DNSTAPREAD dnstap.out | grep "RR " | wc -l`
-	uq4=`$DNSTAPREAD dnstap.out | grep "UQ " | wc -l`
-	ur4=`$DNSTAPREAD dnstap.out | grep "UR " | wc -l`
+	udp4=$($DNSTAPREAD dnstap.out | grep "UDP " | wc -l)
+	tcp4=$($DNSTAPREAD dnstap.out | grep "TCP " | wc -l)
+	aq4=$($DNSTAPREAD dnstap.out | grep "AQ " | wc -l)
+	ar4=$($DNSTAPREAD dnstap.out | grep "AR " | wc -l)
+	cq4=$($DNSTAPREAD dnstap.out | grep "CQ " | wc -l)
+	cr4=$($DNSTAPREAD dnstap.out | grep "CR " | wc -l)
+	rq4=$($DNSTAPREAD dnstap.out | grep "RQ " | wc -l)
+	rr4=$($DNSTAPREAD dnstap.out | grep "RR " | wc -l)
+	uq4=$($DNSTAPREAD dnstap.out | grep "UQ " | wc -l)
+	ur4=$($DNSTAPREAD dnstap.out | grep "UR " | wc -l)
 
 	echo_i "checking UDP message counts"
 	ret=0
@@ -588,7 +590,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking TCP message counts"
 	ret=0
@@ -597,7 +599,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking AUTH_QUERY message counts"
 	ret=0
@@ -606,7 +608,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking AUTH_RESPONSE message counts"
 	ret=0
@@ -615,7 +617,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking CLIENT_QUERY message counts"
 	ret=0
@@ -624,7 +626,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking CLIENT_RESPONSE message counts"
 	ret=0
@@ -633,7 +635,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking RESOLVER_QUERY message counts"
 	ret=0
@@ -642,7 +644,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking RESOLVER_RESPONSE message counts"
 	ret=0
@@ -658,7 +660,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking UPDATE_RESPONSE message counts"
 	ret=0
@@ -667,7 +669,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	mv dnstap.out dnstap.out.save
 
@@ -688,16 +690,16 @@ EOF
 	status=$((status + ret))
 	kill $fstrm_capture_pid
 	wait
-	udp4=`$DNSTAPREAD dnstap.out | grep "UDP " | wc -l`
-	tcp4=`$DNSTAPREAD dnstap.out | grep "TCP " | wc -l`
-	aq4=`$DNSTAPREAD dnstap.out | grep "AQ " | wc -l`
-	ar4=`$DNSTAPREAD dnstap.out | grep "AR " | wc -l`
-	cq4=`$DNSTAPREAD dnstap.out | grep "CQ " | wc -l`
-	cr4=`$DNSTAPREAD dnstap.out | grep "CR " | wc -l`
-	rq4=`$DNSTAPREAD dnstap.out | grep "RQ " | wc -l`
-	rr4=`$DNSTAPREAD dnstap.out | grep "RR " | wc -l`
-	uq4=`$DNSTAPREAD dnstap.out | grep "UQ " | wc -l`
-	ur4=`$DNSTAPREAD dnstap.out | grep "UR " | wc -l`
+	udp4=$($DNSTAPREAD dnstap.out | grep "UDP " | wc -l)
+	tcp4=$($DNSTAPREAD dnstap.out | grep "TCP " | wc -l)
+	aq4=$($DNSTAPREAD dnstap.out | grep "AQ " | wc -l)
+	ar4=$($DNSTAPREAD dnstap.out | grep "AR " | wc -l)
+	cq4=$($DNSTAPREAD dnstap.out | grep "CQ " | wc -l)
+	cr4=$($DNSTAPREAD dnstap.out | grep "CR " | wc -l)
+	rq4=$($DNSTAPREAD dnstap.out | grep "RQ " | wc -l)
+	rr4=$($DNSTAPREAD dnstap.out | grep "RR " | wc -l)
+	uq4=$($DNSTAPREAD dnstap.out | grep "UQ " | wc -l)
+	ur4=$($DNSTAPREAD dnstap.out | grep "UR " | wc -l)
 
 	echo_i "checking UDP message counts"
 	ret=0
@@ -706,7 +708,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking TCP message counts"
 	ret=0
@@ -715,7 +717,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking AUTH_QUERY message counts"
 	ret=0
@@ -724,7 +726,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking AUTH_RESPONSE message counts"
 	ret=0
@@ -733,7 +735,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking CLIENT_QUERY message counts"
 	ret=0
@@ -742,7 +744,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking CLIENT_RESPONSE message counts"
 	ret=0
@@ -751,7 +753,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking RESOLVER_QUERY message counts"
 	ret=0
@@ -760,7 +762,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking RESOLVER_RESPONSE message counts"
 	ret=0
@@ -776,7 +778,7 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 
 	echo_i "checking UPDATE_RESPONSE message counts"
 	ret=0
@@ -785,17 +787,17 @@ EOF
 		ret=1
 	}
 	if [ $ret != 0 ]; then echo_i "failed"; fi
-	status=`expr $status + $ret`
+	status=$((status + ret))
 fi
 
 echo_i "checking large packet printing"
 ret=0
 # Expect one occurrence of "opcode: QUERY" below "reponse_message_data" and
 # another one below "response_message".
-lines=`$DNSTAPREAD -y large-answer.fstrm | grep -c "opcode: QUERY"`
+lines=$($DNSTAPREAD -y large-answer.fstrm | grep -c "opcode: QUERY")
 [ $lines -eq 2 ] || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 _test_dnstap_roll() (
     ip="$1"
@@ -804,7 +806,7 @@ _test_dnstap_roll() (
 
     $RNDCCMD -s "${ip}" dnstap -roll "${n}" | sed "s/^/${ns} /" | cat_i &&
     files=$(find "$ns" -name "dnstap.out.[0-9]" | wc -l) &&
-    test "$files" -eq "${n}" && test "$files" -ge "1"
+    test "$files" -eq "${n}" && test "$files" -ge "1" || return 1
 )
 
 
@@ -816,7 +818,7 @@ test_dnstap_roll() {
 	while test $try -lt 12
 	do
 		touch "$3/dnstap.out.$try"
-		try=`expr $try + 1`
+		try=$((try + 1))
 	done
 
 	_repeat 10 _test_dnstap_roll $2 $3 $4 || ret=1
