@@ -11,6 +11,8 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
+set -e
+
 . ../conf.sh
 
 DIGOPTS="+nosea +stat +noquest +nocomm +nocmd -p ${PORT}"
@@ -19,28 +21,27 @@ status=0
 
 echo_i "Getting message size with compression enabled"
 $DIG $DIGOPTS -b 10.53.0.1 @10.53.0.1 mx example > dig.compen.test
-COMPEN=`grep ';; MSG SIZE' dig.compen.test |sed -e "s/.*: //g"`
+COMPEN=$(grep ';; MSG SIZE' dig.compen.test |sed -e "s/.*: //g")
 cat dig.compen.test  |grep -v ';;' |sort > dig.compen.sorted.test
 
 echo_i "Getting message size with compression disabled"
 $DIG $DIGOPTS -b 10.53.0.2 @10.53.0.1 mx example > dig.compdis.test
-COMPDIS=`grep ';; MSG SIZE' dig.compdis.test |sed -e "s/.*: //g"`
+COMPDIS=$(grep ';; MSG SIZE' dig.compdis.test |sed -e "s/.*: //g")
 cat dig.compdis.test  |grep -v ';;' |sort > dig.compdis.sorted.test
 
 # the compression disabled message should be at least twice as large as with
 # compression disabled, but the content should be the same
 echo_i "Checking if responses are identical other than in message size"
-$DIFF dig.compdis.sorted.test dig.compen.sorted.test >/dev/null
-ret=$?
+{ diff dig.compdis.sorted.test dig.compen.sorted.test >/dev/null; ret=$?; } || true
 if [ $ret != 0 ]; then echo_i "failed"; fi
-status=`expr $status + $ret`
+status=$((status + ret))
 
 echo_i "Checking if message with compression disabled is significantly larger"
 echo_i "Disabled $COMPDIS vs enabled $COMPEN"
-val=`expr \( $COMPDIS \* 3 / 2 \) / $COMPEN`
+val=$(( (COMPDIS * 3 / 2) / COMPEN))
 if [ $val -le 1 ]; then
 	echo_i "failed"
-	status=`expr $status + 1`
+	status=$((status + 1))
 fi;
 
 echo_i "exit status: $status"
