@@ -17,12 +17,12 @@ zone=example.
 infile=example.db.in
 outfile=example.db.bad
 
-for i in Xexample.+005+51829.key Xexample.+005+51829.private \
-	Xexample.+005+05896.key Xexample.+005+05896.private
+for i in Xexample.+008+51650.key Xexample.+008+51650.private \
+	 Xexample.+008+52810.key Xexample.+008+52810.private
 do
-	cp $i `echo $i | sed s/X/K/`
+	cp $i $(echo $i | sed s/X/K/)
 done
 
 $SIGNER -g -s 20000101000000 -e 20361231235959 -o $zone \
-	$infile Kexample.+005+51829 Kexample.+005+51829 \
+	$infile Kexample.+008+52810.key \
 	> /dev/null 2> signer.err || true
